# [Unreleased](https://github.com/Saransh-cpp/riemapp)

# [v0.1.1](https://github.com/Saransh-cpp/riemapp/tree/v0.1.1)

- Minor patch

# [v0.1.0](https://github.com/Saransh-cpp/riemapp/tree/v0.1.0)

- Added `riemapp` geometries as an alias to `manim` geometries
- Added `ComplexMap` to generate complex mappings
